@@ -3,6 +3,18 @@ import click
 from ..utils import bigcommerce
 
 
+@click.command()
+@click.argument('customer_id')
+def customers(customer_id):
+    """ Request '/customers/<customer_id>' endpoint. """
+    bc_customer = bigcommerce.CustomersV2.get(resource_id=customer_id)
+    full_name = f'{bc_customer["first_name"].strip()} {bc_customer["last_name"].strip()}'
+
+    if click.confirm(f'Delete ({customer_id}) {full_name}?'):
+        bigcommerce.CustomersV2.delete(customer_id)
+        click.echo(f'Deleted ({customer_id}) {full_name}.')
+
+
 @click.command()
 @click.argument('product_id')
 def products(product_id):
@@ -15,12 +27,13 @@ def products(product_id):
 
 
 @click.command()
-@click.argument('customer_id')
-def customers(customer_id):
-    """ Request '/customers/<customer_id>' endpoint. """
-    bc_customer = bigcommerce.CustomersV2.get(resource_id=customer_id)
-    full_name = f'{bc_customer["first_name"].strip()} {bc_customer["last_name"].strip()}'
+@click.argument('webhook_id')
+def webhooks(webhook_id):
+    """ Request '/hooks/<webhook_id>' endpoint. """
+    bc_webhook = bigcommerce.Webhooks.get(resource_id=webhook_id)
 
-    if click.confirm(f'Delete ({customer_id}) {full_name}?'):
-        bigcommerce.CustomersV2.delete(customer_id)
-        click.echo(f'Deleted ({customer_id}) {full_name}.')
+    if click.confirm(f'Delete ({webhook_id}) with scope \'{bc_webhook["scope"]}\''):
+        # BC expects that you deactivate a webhook before deleting it
+        bigcommerce.Webhooks.put(resource_id=webhook_id, json={'is_active': False})
+        bigcommerce.Webhooks.delete(resource_id=webhook_id)
+        click.echo(f'Deleted ({webhook_id})')
